import { default as EventEmitter } from 'eventemitter3';
import { EventType } from "../EventType";
import ElementInterface from '../ElementInterface';
import { ValueType } from './ValueType';
export default abstract class AbstractElement implements ElementInterface {
    private readonly htmlContainer;
    private label;
    private eventEmitter;
    private elementValue;
    constructor();
    /** the current value of the element */
    get value(): ValueType;
    protected abstract getInput(): HTMLElement;
    getHtmlElement(): HTMLElement;
    setValue(value: ValueType): void;
    /** sets the label to the passed value */
    setLabel(label: string): this;
    /**
     * allows to set a callback to be called on every change. based on the return value of the callback this element
     * will be shown (when true) or hidden (when false).
     */
    showOn(callback: () => boolean): this;
    /** @internal */
    on<K extends keyof EventType>(eventname: K, callback: EventEmitter.EventListener<EventType, K>): void;
    /** @internal */
    reportSettingsChange(): void;
    protected createLabel(): HTMLElement | undefined;
    protected changeValue(value: string): void;
}
