import { default as EventEmitter } from 'eventemitter3';
import Headline from "./details/Headline";
import HtmlElement from "./details/HtmlElement";
import Paragraph from "./details/Paragraph";
import Summary from "./details/Summary";
import HtmlElementInterface from "../HtmlElementInterface";
export default class Details {
    constructor() {
        this.elements = [];
        this.eventEmitter = new EventEmitter();
    }
    getHtmlElement() {
        const detailsElement = document.createElement('details');
        for (const element of this.elements) {
            detailsElement.append(element.getHtmlElement());
        }
        return detailsElement;
    }
    /** adds a summary to the details (the clickable text that still shows when the details are collapsed) */
    addSummary(text) {
        this.elements.push(new Summary(text));
        return this;
    }
    /** adds a headline to the details */
    addHeadline(text) {
        this.elements.push(new Headline(text));
        return this;
    }
    /** adds a paragraph to the details */
    addParagraph(text) {
        const paragraph = new Paragraph(text);
        paragraph.onLinkClick((event) => this.eventEmitter.emit('click', event));
        this.elements.push(paragraph);
        return this;
    }
    /** allows to add any html element to the details */
    addElement(element) {
        this.elements.push(new HtmlElement(element));
        return this;
    }
    /**
     * attaches an event listener that gets called when the user clicks a link inside a paragraph
     * @internal
     */
    onLinkClick(callback) {
        this.eventEmitter.on('click', callback);
    }
}
