import { is } from 'ts-type-guards';
import AbstractElement from './AbstractElement';
export default class Dropdown extends AbstractElement {
    constructor() {
        super(...arguments);
        this.options = [];
    }
    /**
     * Adds one selectable option to the dropdown
     * @param {string} label The text to display
     * @param {string} value The value, that will be used internally when the option was selected
     */
    addOption(label, value) {
        this.options.push({ label, value });
        return this;
    }
    getInput() {
        var _a;
        if (this.select) {
            return this.select;
        }
        this.select = document.createElement('select');
        this.select.classList.add('sdpi-item-value', 'select');
        const optionElements = this.options.map((opt) => {
            const option = document.createElement('option');
            option.value = opt.value;
            option.text = opt.label;
            return option;
        });
        for (const optionElement of optionElements) {
            (_a = this.select) === null || _a === void 0 ? void 0 : _a.append(optionElement);
        }
        this.select.addEventListener('change', (error) => this.onChange(error));
        return this.select;
    }
    onChange(event) {
        if (is(HTMLSelectElement)(event.target)) {
            this.changeValue(event.target.value);
        }
    }
}
